@@ -8,6 +8,9 @@ Wisdom is the user interaction with Whatify wisdom, it contains
 # ‘Prediction’ API includes querying of predictions (Get, List and Delete) and creating a Prediction to get predictions
 # on existing Ensembles and uploaded Datasources.
 import os
+
+import s3fs
+
 import toolkit_w
 from toolkit_w.internal.api_requestor import APIRequestor
 from toolkit_w.internal.whatify_response import WhatifyResponse
@@ -74,7 +77,7 @@ class UserManagement(APIResource):
         if user_token is None:
             user_token = toolkit_w.token
         response = requester.get(url, params={'jwt': user_token})
-        return response.json().get('result', response.json())
+        return response
 
     @classmethod
     def get_client_path(cls, user_token: str = None):
@@ -85,7 +88,9 @@ class UserManagement(APIResource):
         os.environ['AWS_DEFAULT_REGION'] = credentials['region']
         bucket = credentials['bucket']
         PATH = credentials['path']
-        return f's3://{bucket}/{PATH}/'
+        s3_path = f's3://{bucket}/{PATH}/'
+        fs = s3fs.S3FileSystem()
+        return fs.ls(s3_path)
 
 
 
