@@ -354,9 +354,7 @@ class MyWhatify:
 
     @classmethod
     def ls_client(cls, user_token: str = None):
-        path = my_toolkit.UserManagement.get_client_path(user_token=user_token)
-        fs = s3fs.S3FileSystem()
-        return fs.ls(path)
+        return my_toolkit.UserManagement.get_client_path(user_token=user_token)
 
     @classmethod
     def get_s3_boto_client(cls, user_token: str = None):
